==> bb-foundation-0.0.6.tgz: package/README.md <==
# bb-foundation

> The Angular core foundation of the Bravobit team.

[![npm version](https://badge.fury.io/js/%40bravobit%2Fbb-foundation.svg)](https://www.npmjs.com/package/@bravobit/bb-foundation)
[![npm license](https://img.shields.io/badge/license-MIT-green.svg)](LICENSE)

- Use <kbd>⌘ Command</kbd> + <kbd>F</kbd> or <kbd>ctrl</kbd> + <kbd>F</kbd> to search for a keyword.
- Contributions welcome, please see [contribution guide](.github/CONTRIBUTING.md).

## Features

* Easy implementation
* Library can be consumed by Angular CLI, Webpack, or SystemJS
* Compatibility
  * Angular Universal
  * Ahead-Of-Time compilation (AOT)
  * Lazy loading

## Installation

To use bb-foundation in your project install it via `npm` or `yarn`:

```bash
$ npm install @bravobit/bb-foundation --save

# or

$ yarn add @bravobit/bb-foundation
```

## Setup

Add the `BbDashboardModule` or `BbNotificationsModule` to your imports array in your `AppModule`.

```typescript
import {BrowserModule} from '@angular/platform-browser';
import {NgModule} from '@angular/core';
import {BrowserAnimationsModule} from '@angular/platform-browser/animations';
import {BbDashboardModule, BbNotificationsModule} from '@bravobit/bb-foundation';

import {AppComponent} from './app.component';

@NgModule({
    imports: [
        BrowserModule, 
        BrowserAnimationsModule, // required for the notifications.
        BbDashboardModule,
        BbNotificationsModule.forRoot({/*Optional*/}),
    ],
    declarations: [AppComponent],
    bootstrap: [AppComponent]
})
export class AppModule {
}
```

## Example

Check the playground for an example.

==> bb-foundation-0.1.1.tgz: package/README.md <==
# bb-foundation

> The Angular core foundation of the Bravobit team.

[![npm version](https://badge.fury.io/js/%40bravobit%2Fbb-foundation.svg)](https://www.npmjs.com/package/@bravobit/bb-foundation)
[![npm license](https://img.shields.io/badge/license-MIT-green.svg)](LICENSE)

- Use <kbd>⌘ Command</kbd> + <kbd>F</kbd> or <kbd>ctrl</kbd> + <kbd>F</kbd> to search for a keyword.
- Contributions welcome, please see [contribution guide](.github/CONTRIBUTING.md).

## Features

* Easy implementation
* Library can be consumed by Angular CLI, Webpack, or SystemJS
* Compatibility
  * Angular Universal
  * Ahead-Of-Time compilation (AOT)
  * Lazy loading

## Installation

To use bb-foundation in your project install it via `npm` or `yarn`:

```bash
$ npm install @bravobit/bb-foundation --save

# or

$ yarn add @bravobit/bb-foundation
```

## Setup

Add the `BbDashboardModule` or `BbNotificationsModule` to your imports array in your `AppModule`.

```typescript
import {BrowserModule} from '@angular/platform-browser';
import {NgModule} from '@angular/core';
import {BrowserAnimationsModule} from '@angular/platform-browser/animations';
import {BbDashboardModule, BbNotificationsModule, BbTranslateModule} from '@bravobit/bb-foundation';

import {AppComponent} from './app.component';

@NgModule({
    imports: [
        BrowserModule, 
        BrowserAnimationsModule, // required for the notifications.
        BbDashboardModule,
        BbNotificationsModule.forRoot({/*Optional*/}),
        BbTranslateModule.forRoot({
            production: false,
            dictionary: [
                {
                    data: {
                        'global.string': 'This string has interpolation: {variable}.'
                    },
                    languages: ['en-EN', 'en'],
                    name: 'English'
                }
            ]
        })
    ],
    declarations: [AppComponent],
    bootstrap: [AppComponent]
})
export class AppModule {
}
```

## Example

Check the playground for an example.
